pub struct ConnTrackConfig {
pub max_connections: usize,
pub max_out_of_order: usize,
pub timeout_resolution: usize,
pub udp_inactivity_timeout: usize,
pub tcp_inactivity_timeout: usize,
pub tcp_reassembly_timeout: usize,
pub tcp_establish_timeout: usize,
/* private fields */
}Expand description
Connection tracking options.
These options can be used to tune for resource usage vs. accuracy depending on expected network characteristics.
Example
[conntrack]
max_connections = 10_000_000
max_out_of_order = 100
timeout_resolution = 100
udp_inactivity_timeout = 60_000
tcp_inactivity_timeout = 300_000
tcp_establish_timeout = 5000Fields
max_connections: usizeMaximum number of connections that can be tracked simultaneously per-core. Defaults to
10_000_000.
max_out_of_order: usizeMaximum number of out-of-order packets allowed per TCP connection before it is force
expired. Defaults to 100.
timeout_resolution: usizeFrequency to check for inactive streams (in milliseconds). Defaults to 1000 (1 second).
udp_inactivity_timeout: usizeA UDP connection can be inactive for up to this amount of time (in milliseconds) before it
is force expired. Defaults to 60_000 (1 minute).
tcp_inactivity_timeout: usizeA TCP connection can be inactive for up to this amount of time (in milliseconds) before it
is force expired. Defaults to 300_000 (5 minutes).
tcp_reassembly_timeout: usizeOverride the default TCP connection inactivity timeout with this value (in milliseconds) if there are unfilled sequence number gaps.
Defaults to tcp_inactivity_timeout. This is used to prevent memory exhaustion
on networks where there may be loss between the ground truth TCP connection (guaranteed retransmissions)
and the monitoring vantage point (retransmissions not guaranteed).
tcp_establish_timeout: usizeInactivity time between the first and second packet of a TCP connection before it is force expired (in milliseconds).
This approximates connections that remain inactive in either the SYN-SENT or
SYN-RECEIVED state without progressing. It is used to prevent memory exhaustion due to SYN
scans and SYN floods. Defaults to 5000 (5 seconds).