pub struct LogConfig {
pub directory: String,
pub interval: u64,
pub port_stats: Vec<String>,
}Expand description
Logging options.
Example
[online.monitor.log]
directory = "./log"
interval = 1000
port_stats = ["rx"] # only log stats with "rx" in its nameFields
directory: StringLog directory path. If logging is enabled, Iris will write logs to a timestamped folder
inside directory. Defaults to "./log".
interval: u64How often to log port statistics (in milliseconds). Defaults to 1000.
port_stats: Vec<String>List of port statistics to log.
Available options vary depending on the NIC driver and its supported counters. A port
statistic will be logged if it contains (as a substring) any item in the port_stats list.
To log all available port statistics, set this value to a list containing the empty string
(port_stats = [""]). Defaults to logging receive statistics (port_stats = ["rx"]).