pub struct RuntimeConfig {
pub main_core: u32,
pub nb_memory_channels: usize,
pub suppress_dpdk_output: bool,
pub mempool: MempoolConfig,
pub online: Option<OnlineConfig>,
pub offline: Option<OfflineConfig>,
pub conntrack: ConnTrackConfig,
/* private fields */
}Expand description
Runtime configuration options.
Fields
main_core: u32Main core identifier. Initializes and manages packet processing cores and logging, but does not process packets itself.
nb_memory_channels: usizeSets the number of memory channels to use.
This controls the spread layout used by the memory allocator and is mainly for performance
optimization. Can be configured up to be the number of channels per CPU socket if the
platform supports multiple memory channels. Defaults to 1.
suppress_dpdk_output: boolSuppress DPDK runtime logging and telemetry output. Defaults to true.
mempool: MempoolConfigPer-mempool settings.
online: Option<OnlineConfig>Online mode settings. Either online or offline must be specified.
offline: Option<OfflineConfig>Offline mode settings. Either online or offline must be specified.
conntrack: ConnTrackConfigConnection tracking settings.
Implementations
Sourceimpl RuntimeConfig
impl RuntimeConfig
Sourcepub fn get_all_core_ids(&self) -> Vec<CoreId>
pub fn get_all_core_ids(&self) -> Vec<CoreId>
Returns a list of core IDs assigned to the runtime.
pub fn get_all_rx_core_ids(&self) -> Vec<CoreId>