pub struct SinkConfig {
pub core: u32,
pub nb_buckets: usize,
}Expand description
Sink core options.
A “sink” core is a utility core whose sole purpose is to drop received traffic. This is useful for connection sampling, as entire 4-tuples can be discarded by redirecting them to the sink core.
Remarks
Adding a sink core prevents ethtool counters from classifying intentionally discarded packets as packet loss. However, it can be quite wasteful of system resources, as it requires configuring one additional core per interface and thrashes the cache.
Example
[online.ports.sink]
core = 9
nb_buckets = 384 # drops 25% of 4-tuplesFields
core: u32Sink core identifier.
nb_buckets: usizeNumber of RSS redirection table buckets to use for receive queues. Defaults to 512, which
indicates no sampling.
Remarks
Connection sampling is implemented by only polling from a fraction of the available RSS
redirection buckets. nb_buckets must range from the number of cores polling the port (call
this n) to 512, which is the maximum number of buckets in the RSS redirection table. It
is recommended that nb_buckets be a multiple of n for better load balancing. For
example, setting nb_buckets = 256 would drop 50% of connections.